#include <QDBusInterface>
#include <QDBusConnection>

#include "udisksdevice.h"


UDisksDevice::UDisksDevice(QDBusObjectPath o, QObject *parent)
        : QObject(parent)
{
    m_interface = new QDBusInterface("org.freedesktop.UDisks", o.path(),
                                     "org.freedesktop.UDisks.Device", QDBusConnection::systemBus(), this);
    m_interface->connection().connect("org.freedesktop.UDisks", o.path(),
                                      "org.freedesktop.UDisks.Device","Changed",
                                      this, SIGNAL(changed()));
    m_path = o;

    QStringList media=property("DriveMediaCompatibility").toStringList();
    m_isDvd=false;
    m_isBurner=false;
    m_volumeName="";
    m_device="";
    if (media.contains("optical_dvd")) {
        m_isDvd=true;
        m_device=property("DeviceFile").toString();
        m_volumeName=property("IdLabel").toString();
        m_name=QString("%1 %2").arg(property("DriveVendor").toString()).arg(property("DriveModel").toString());
        if(media.contains("optical_dvd_rw") || media.contains("optical_dvd_plus_rw") || media.contains("optical_mrw"))
            m_isBurner=true;
    }
}

QVariant UDisksDevice::property (const QString &key)
{
    return m_interface->property(key.toAscii().data());
}

UDisksDevice::~UDisksDevice()
{
}

QDBusObjectPath UDisksDevice::objectPath() const
{
    return m_path;
}

bool UDisksDevice::isDVD() {
    return m_isDvd;
}
bool UDisksDevice::isBurner() {
    return m_isBurner;
}

QString UDisksDevice::getVolumeName() {
    return m_volumeName;
}
void UDisksDevice::setVolumeName(const QString & _volName) {
    m_volumeName=_volName;
}

QString UDisksDevice::getDevice() {
    return m_device;
}

QString UDisksDevice::getName() {
    return m_name;

}
