#include <QDBusInterface>
#include <QDBusConnection>
#include <QDBusReply>

#include "udisksmanager.h"

UDisksManager::UDisksManager(QObject *parent)
        : QObject(parent)
{
    m_interface = new QDBusInterface("org.freedesktop.UDisks", "/org/freedesktop/UDisks",
                                     "org.freedesktop.UDisks", QDBusConnection::systemBus(), this);

    m_interface->connection().connect("org.freedesktop.UDisks", "/org/freedesktop/UDisks",
                                      "org.freedesktop.UDisks", "DeviceAdded",
                                      this, SIGNAL(deviceAdded(QDBusObjectPath)));

    m_interface->connection().connect("org.freedesktop.UDisks", "/org/freedesktop/UDisks",
                                      "org.freedesktop.UDisks", "DeviceRemoved",
                                      this, SIGNAL(deviceRemoved(QDBusObjectPath)));

    m_interface->connection().connect("org.freedesktop.UDisks", "/org/freedesktop/UDisks",
                                      "org.freedesktop.UDisks", "DeviceChanged",
                                      this, SIGNAL(deviceChanged(QDBusObjectPath)));

    connect (this,SIGNAL(deviceAdded(QDBusObjectPath)),SLOT(sdeviceAdded(QDBusObjectPath)));
    connect (this,SIGNAL(deviceRemoved(QDBusObjectPath)),SLOT(sdeviceRemoved(QDBusObjectPath)));
    connect (this,SIGNAL(deviceChanged(QDBusObjectPath)),SLOT(sdeviceChanged(QDBusObjectPath)));
}


UDisksManager::~UDisksManager()
{
}

void UDisksManager::sdeviceChanged(QDBusObjectPath o) {
   UDisksDevice *device = new UDisksDevice(o, this);
   foreach(UDisksDevice *dev,m_devices) {
       if ((dev->objectPath()==device->objectPath())&& (dev->getVolumeName()!=device->getVolumeName())) {
           emit (volumeChanged(device->getDevice(),device->getVolumeName()));
           dev->setVolumeName(device->getVolumeName());
       }

   }
   delete device;
}

void UDisksManager::sdeviceRemoved(QDBusObjectPath o) {

}

void UDisksManager::sdeviceAdded(QDBusObjectPath o) {
    foreach(UDisksDevice *device, m_devices)
    {
        if (device->objectPath() == o)
            return;
    }

    UDisksDevice *device = new UDisksDevice(o, this);

    if (device->isDVD()) {
         // qDebug("UDisksPlugin: device \"%s\" ", qPrintable(o.path()));
          QString s=device->getVolumeName() +" "+device->getDevice();
          //qDebug("UDisksPlugin: device \"%s\" ", qPrintable(s));
          m_devices << device;
          emit driveAdded(device->getDevice(),device->getName(),device->isBurner(),QStringList () <<"3324" <<"5540"<< "8310" << "11080" << "22160");
        return;
    }

    delete device;
}

QList<QDBusObjectPath> UDisksManager::findAllDevices()
{
    m_devices.clear();
    QDBusReply <QList<QDBusObjectPath> > reply = m_interface->call("EnumerateDevices");
    if (!reply.isValid())
    {
        qWarning("UDisksManager: error: %s", qPrintable(reply.error().name()));
        return QList<QDBusObjectPath>();
    }
   foreach(QDBusObjectPath o, reply.value()) {
        emit deviceAdded(o);
    }

    return reply.value();
}
